==> haskell-gtk-sni-tray-0.1.8.1-384-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-gtk-sni-tray.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gtk-sni-tray
version:                0.1.8.1
visibility:             public
id:                     gtk-sni-tray-0.1.8.1-3ywlwJjGSTzKmadBCWmujz
key:                    gtk-sni-tray-0.1.8.1-3ywlwJjGSTzKmadBCWmujz
license:                BSD-3-Clause
copyright:              2018 Ivan Malison
maintainer:             IvanMalison@gmail.com
author:                 Ivan Malison
homepage:               https://github.com/IvanMalison/gtk-sni-tray#readme
synopsis:               A standalone StatusNotifierItem/AppIndicator tray
description:
    Please see the README on Github at <https://github.com/IvanMalison/gtk-sni-tray#readme>

category:               System
abi:                    54ea69f8e8794bfc93caf15167d90a7d
exposed:                True
exposed-modules:        StatusNotifier.TransparentWindow StatusNotifier.Tray
hidden-modules:         Paths_gtk_sni_tray
import-dirs:            /usr/lib/ghc-9.6.6/site-local/gtk-sni-tray-0.1.8.1
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/gtk-sni-tray-0.1.8.1 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/gtk-sni-tray-0.1.8.1 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-gtk-sni-tray
hs-libraries:           HSgtk-sni-tray-0.1.8.1-3ywlwJjGSTzKmadBCWmujz
extra-libraries:
    gtk-3 gdk-3 z pangocairo-1.0 cairo-gobject gdk_pixbuf-2.0 atk-1.0
    pango-1.0 cairo harfbuzz gio-2.0 gobject-2.0 glib-2.0

extra-libraries-static:
    gtk-3 gdk-3 z pangocairo-1.0 m Xrandr Xcursor Xcomposite Xdamage
    Xinerama cloudproviders cairo-gobject m dl gdk_pixbuf-2.0 m
    glycin-2 seccomp lcms2 pthread atk-bridge-2.0 atspi Xtst Xi Xfixes
    atk-1.0 dbus-1 systemd cap xkbcommon wayland-cursor wayland-egl
    wayland-client m rt epoxy dl GL EGL pangoft2-1.0 m pango-1.0 m
    fribidi thai datrie Xft cairo m dl fontconfig m expat m Xext
    Xrender X11 pthread xcb-render xcb-shm xcb Xau Xdmcp pixman-1 m
    harfbuzz-gobject harfbuzz m freetype dl bz2 png16 m m brotlidec
    brotlicommon graphite2 gio-2.0 gobject-2.0 ffi gmodule-2.0 glib-2.0
    m pcre2-8 pthread z mount blkid sysprof-capture-4

include-dirs:
    /usr/include/gtk-3.0 /usr/include/pango-1.0 /usr/include
    /usr/include/cloudproviders /usr/include/cairo
    /usr/include/gdk-pixbuf-2.0 /usr/include/glycin-2
    /usr/include/at-spi2-atk/2.0 /usr/include/at-spi-2.0
    /usr/include/atk-1.0 /usr/include/dbus-1.0
    /usr/lib/dbus-1.0/include /usr/include/fribidi
    /usr/include/pixman-1 /usr/include/harfbuzz /usr/include/freetype2
    /usr/include/libpng16 /usr/include/gio-unix-2.0
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6

depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    dbus-1.3.3-I7Q67QGi2CK1IKKmdebsoN directory-1.3.8.5
    enclosed-exceptions-1.0.3-IH7IgGKTEJFJLmctIAPJiT filepath-1.4.300.1
    gi-cairo-1.0.30-JvrMs0LU63XF0FZSBbee7J
    gi-cairo-connector-0.1.1-EyrfjUCMp82FG80AfoXmIM
    gi-cairo-render-0.1.2-A9Nry2lvrWG67ohsW0bHB
    gi-dbusmenugtk3-0.4.15-3FwAzHbMGAf5Zcw4i0mQ2N
    gi-gdk-3.0.29-IjqrlTmXxDIKTyIOtnIEV
    gi-gdkpixbuf-2.0.32-mb2P66jP5gAIamckoTbA2
    gi-glib-2.0.30-FvdeU4nNzqAALCjAH2Z0rR
    gi-gtk-3.0.43-2YGdBsPsy8b6gP805A8iv8
    gtk-strut-0.1.3.2-RPNTLEvW9s5PbEBrvbgC8
    haskell-gi-0.26.16-DRMB6Y9Bskv7maGoKfpb8b
    haskell-gi-base-0.26.9-9dGlnSJnubc2h9MiqHeprA
    hslogger-1.3.2.0-H4OZ1FZbeeNMbSjFBgOfV
    status-notifier-item-0.3.1.0-HBFDZo4OHT4BjDjChEgVfb text-2.0.2
    transformers-0.6.1.0 transformers-base-0.4.6-IFFPlbMue7bJmNu16qahDQ
    unix-2.8.4.0

haddock-interfaces:
    /usr/share/doc/haskell-gtk-sni-tray/html/gtk-sni-tray.haddock

haddock-html:           /usr/share/doc/haskell-gtk-sni-tray/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gtk-sni-tray-0.1.8.1-385-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-gtk-sni-tray.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gtk-sni-tray
version:                0.1.8.1
visibility:             public
id:                     gtk-sni-tray-0.1.8.1-AnNusoqeoig6gpquFqQDwd
key:                    gtk-sni-tray-0.1.8.1-AnNusoqeoig6gpquFqQDwd
license:                BSD-3-Clause
copyright:              2018 Ivan Malison
maintainer:             IvanMalison@gmail.com
author:                 Ivan Malison
homepage:               https://github.com/IvanMalison/gtk-sni-tray#readme
synopsis:               A standalone StatusNotifierItem/AppIndicator tray
description:
    Please see the README on Github at <https://github.com/IvanMalison/gtk-sni-tray#readme>

category:               System
abi:                    9a069b21d1cd0f7ca3e03af5bce107a4
exposed:                True
exposed-modules:        StatusNotifier.TransparentWindow StatusNotifier.Tray
hidden-modules:         Paths_gtk_sni_tray
import-dirs:            /usr/lib/ghc-9.6.6/site-local/gtk-sni-tray-0.1.8.1
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/gtk-sni-tray-0.1.8.1 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/gtk-sni-tray-0.1.8.1 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-gtk-sni-tray
hs-libraries:           HSgtk-sni-tray-0.1.8.1-AnNusoqeoig6gpquFqQDwd
extra-libraries:
    gtk-3 gdk-3 z pangocairo-1.0 cairo-gobject gdk_pixbuf-2.0 atk-1.0
    pango-1.0 cairo harfbuzz gio-2.0 gobject-2.0 glib-2.0

extra-libraries-static:
    gtk-3 gdk-3 z pangocairo-1.0 m Xrandr Xcursor Xcomposite Xdamage
    Xinerama cloudproviders cairo-gobject m dl gdk_pixbuf-2.0 m
    glycin-2 seccomp lcms2 pthread atk-bridge-2.0 atspi Xtst Xi Xfixes
    atk-1.0 dbus-1 systemd cap xkbcommon wayland-cursor wayland-egl
    wayland-client m rt epoxy dl GL EGL pangoft2-1.0 m pango-1.0 m
    fribidi thai datrie Xft cairo m dl fontconfig m expat m Xext
    Xrender X11 pthread xcb-render xcb-shm xcb Xau Xdmcp pixman-1 m
    harfbuzz-gobject harfbuzz m freetype dl bz2 png16 m m brotlidec
    brotlicommon graphite2 gio-2.0 gobject-2.0 ffi gmodule-2.0 glib-2.0
    atomic m pcre2-8 pthread z mount blkid sysprof-capture-4

include-dirs:
    /usr/include/gtk-3.0 /usr/include/pango-1.0 /usr/include
    /usr/include/cloudproviders /usr/include/cairo
    /usr/include/gdk-pixbuf-2.0 /usr/include/glycin-2
    /usr/include/at-spi2-atk/2.0 /usr/include/at-spi-2.0
    /usr/include/atk-1.0 /usr/include/dbus-1.0
    /usr/lib/dbus-1.0/include /usr/include/fribidi
    /usr/include/pixman-1 /usr/include/harfbuzz /usr/include/freetype2
    /usr/include/libpng16 /usr/include/gio-unix-2.0
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6

depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    dbus-1.3.3-INvnWTkkmrECqNpDSboXTA directory-1.3.8.5
    enclosed-exceptions-1.0.3-IH7IgGKTEJFJLmctIAPJiT filepath-1.4.300.1
    gi-cairo-1.0.30-3N3cPtJzja7DTX2BJ7V7xB
    gi-cairo-connector-0.1.1-16jVEhb1XppLGgNrWp2GkA
    gi-cairo-render-0.1.2-2ZkwwnDvqZE7HgzghN0Wyd
    gi-dbusmenugtk3-0.4.15-GbFzMimrRdJLcH0G3xrFz1
    gi-gdk-3.0.29-3leWBDJTALFbfD3qiC00E
    gi-gdkpixbuf-2.0.32-352bJfxvRUfBaqStpZyEi6
    gi-glib-2.0.30-4ukFl75YXpe5LupxQnESOJ
    gi-gtk-3.0.43-9A6QPuGdBMpAA8CnLgcM1f
    gtk-strut-0.1.3.2-K26rEF3v1afA85QEy6fNaf
    haskell-gi-0.26.16-2upsUGeF8es9hG6LJvJTcE
    haskell-gi-base-0.26.9-9dGlnSJnubc2h9MiqHeprA
    hslogger-1.3.2.0-1NkMetVZZQxCHjmQHJSTJK
    status-notifier-item-0.3.1.0-J5CDIQT3Ba69Y8zmhyoIc0 text-2.0.2
    transformers-0.6.1.0 transformers-base-0.4.6-IFFPlbMue7bJmNu16qahDQ
    unix-2.8.4.0

haddock-interfaces:
    /usr/share/doc/haskell-gtk-sni-tray/html/gtk-sni-tray.haddock

haddock-html:           /usr/share/doc/haskell-gtk-sni-tray/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
